@@ -65,6 +65,7 @@ gupnp_root_device_finalize (GObject *object)
 
         device = GUPNP_ROOT_DEVICE (object);
 
+        g_object_unref (device->priv->description_doc);
         g_free (device->priv->description_path);
         g_free (device->priv->description_dir);
         g_free (device->priv->relative_location);
@@ -87,11 +88,6 @@ gupnp_root_device_dispose (GObject *object)
                 device->priv->group = NULL;
         }
 
-        if (device->priv->description_doc) {
-                g_object_unref (device->priv->description_doc);
-                device->priv->description_doc = NULL;
-        }
-
         /* Call super */
         object_class = G_OBJECT_CLASS (gupnp_root_device_parent_class);
         object_class->dispose (object);
@@ -439,7 +435,7 @@ gupnp_root_device_constructor (GType                  type,
                       "url-base", url_base,
                       NULL);
 
-	soup_uri_free (url_base);
+        soup_uri_free (url_base);
 
         /* Create resource group */
         device->priv->group = gssdp_resource_group_new (GSSDP_CLIENT (context));
@@ -457,6 +453,7 @@ gupnp_root_device_constructor (GType                  type,
 
  DONE:
         /* Cleanup */
+        g_free (desc_path);
         g_free (location);
 
         return object;
